==> ejc-supbid-api-3.0.1-20211125.081748-19-sources.jar: com/ejianc/business/supbid/winbid/vo/WinbidVO.java <==
package com.ejianc.business.supbid.winbid.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 中标实体
 * 
 * @author generator
 * 
 */
@ApiModel("中标实体")
public class WinbidVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("来源id")
    private java.lang.String sourceId;
    @ApiModelProperty("中标编号")
    private java.lang.String billCode;
    @ApiModelProperty("发布项目ID")
    private java.lang.String sourceProjectId;
    @ApiModelProperty("发布项目名称")
    private java.lang.String projectName;
    @ApiModelProperty("发布项目编号")
    private java.lang.String projectCode;
    @ApiModelProperty("发布组织ID")
    private java.lang.String sourceOrgId;
    @ApiModelProperty("发布组织名称")
    private java.lang.String orgName;
    @ApiModelProperty("招标单位ID")
    private java.lang.String sourceUnitId;
    @ApiModelProperty("招标单位名称")
    private java.lang.String unitName;
    @ApiModelProperty("备注")
    private java.lang.String memo;
    @ApiModelProperty("类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)")
    private java.lang.String type;
    @ApiModelProperty("招标名称")
    private java.lang.String tenderName;
    @ApiModelProperty("招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)")
    private java.lang.Integer tenderType;
    @ApiModelProperty("招标联系人")
    private java.lang.String sourceEmployeeId;
    @ApiModelProperty("招标联系人名称")
    private java.lang.String employeeName;
    @ApiModelProperty("招标联系人电话")
    private java.lang.String employeeMobile;
    @ApiModelProperty("采购方式(0-项目采购,1-单位采购)")
    private java.lang.Integer purchaseType;
    @ApiModelProperty("开标时间")
    private java.util.Date noticeBidTime;
    @ApiModelProperty("中标时间")
    private java.util.Date noticeWinbidTime;
    @ApiModelProperty("中标总额")
    private java.math.BigDecimal winbidMoney;
    @ApiModelProperty("中标总额(含税)")
    private java.math.BigDecimal winbidMoneyTax;

    private List<WinbidDetailVO> winbidDetailList = new ArrayList<>(); // 中标明细

    public List<WinbidDetailVO> getWinbidDetailList() {
        return winbidDetailList;
    }

    public void setWinbidDetailList(List<WinbidDetailVO> winbidDetailList) {
        this.winbidDetailList = winbidDetailList;
    }

    /**
     * 来源id
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 来源id
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 中标编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 中标编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发布项目ID
     */
    public java.lang.String getSourceProjectId() {
        return sourceProjectId;
    }

    /**
     * 发布项目ID
     */
    public void setSourceProjectId(java.lang.String sourceProjectId) {
        this.sourceProjectId = sourceProjectId;
    }
    /**
     * 发布项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 发布项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 发布项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 发布项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 发布组织ID
     */
    public java.lang.String getSourceOrgId() {
        return sourceOrgId;
    }

    /**
     * 发布组织ID
     */
    public void setSourceOrgId(java.lang.String sourceOrgId) {
        this.sourceOrgId = sourceOrgId;
    }
    /**
     * 发布组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 发布组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 招标单位ID
     */
    public java.lang.String getSourceUnitId() {
        return sourceUnitId;
    }

    /**
     * 招标单位ID
     */
    public void setSourceUnitId(java.lang.String sourceUnitId) {
        this.sourceUnitId = sourceUnitId;
    }
    /**
     * 招标单位名称
     */
    public java.lang.String getUnitName() {
        return unitName;
    }

    /**
     * 招标单位名称
     */
    public void setUnitName(java.lang.String unitName) {
        this.unitName = unitName;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }
    /**
     * 招标名称
     */
    public java.lang.String getTenderName() {
        return tenderName;
    }

    /**
     * 招标名称
     */
    public void setTenderName(java.lang.String tenderName) {
        this.tenderName = tenderName;
    }
    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public java.lang.Integer getTenderType() {
        return tenderType;
    }

    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public void setTenderType(java.lang.Integer tenderType) {
        this.tenderType = tenderType;
    }
    /**
     * 招标联系人
     */
    public java.lang.String getSourceEmployeeId() {
        return sourceEmployeeId;
    }

    /**
     * 招标联系人
     */
    public void setSourceEmployeeId(java.lang.String sourceEmployeeId) {
        this.sourceEmployeeId = sourceEmployeeId;
    }
    /**
     * 招标联系人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 招标联系人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 招标联系人电话
     */
    public java.lang.String getEmployeeMobile() {
        return employeeMobile;
    }

    /**
     * 招标联系人电话
     */
    public void setEmployeeMobile(java.lang.String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }
    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public java.lang.Integer getPurchaseType() {
        return purchaseType;
    }

    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public void setPurchaseType(java.lang.Integer purchaseType) {
        this.purchaseType = purchaseType;
    }
    /**
     * 开标时间
     */
    public java.util.Date getNoticeBidTime() {
        return noticeBidTime;
    }

    /**
     * 开标时间
     */
    public void setNoticeBidTime(java.util.Date noticeBidTime) {
        this.noticeBidTime = noticeBidTime;
    }
    /**
     * 中标时间
     */
    public java.util.Date getNoticeWinbidTime() {
        return noticeWinbidTime;
    }

    /**
     * 中标时间
     */
    public void setNoticeWinbidTime(java.util.Date noticeWinbidTime) {
        this.noticeWinbidTime = noticeWinbidTime;
    }
    /**
     * 中标总额
     */
    public java.math.BigDecimal getWinbidMoney() {
        return winbidMoney;
    }

    /**
     * 中标总额
     */
    public void setWinbidMoney(java.math.BigDecimal winbidMoney) {
        this.winbidMoney = winbidMoney;
    }
    /**
     * 中标总额(含税)
     */
    public java.math.BigDecimal getWinbidMoneyTax() {
        return winbidMoneyTax;
    }

    /**
     * 中标总额(含税)
     */
    public void setWinbidMoneyTax(java.math.BigDecimal winbidMoneyTax) {
        this.winbidMoneyTax = winbidMoneyTax;
    }
    
}

==> ejc-supbid-api-3.0.1-20211206.060931-31-sources.jar: com/ejianc/business/supbid/winbid/vo/WinbidVO.java <==
package com.ejianc.business.supbid.winbid.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 中标实体
 * 
 * @author generator
 * 
 */
@ApiModel("中标实体")
public class WinbidVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("来源id")
    private java.lang.String sourceId;
    @ApiModelProperty("中标编号")
    private java.lang.String billCode;
    @ApiModelProperty("发布项目ID")
    private java.lang.String sourceProjectId;
    @ApiModelProperty("发布项目名称")
    private java.lang.String projectName;
    @ApiModelProperty("发布项目编号")
    private java.lang.String projectCode;
    @ApiModelProperty("发布组织ID")
    private java.lang.String sourceOrgId;
    @ApiModelProperty("发布组织名称")
    private java.lang.String orgName;
    @ApiModelProperty("招标单位ID")
    private java.lang.String sourceUnitId;
    @ApiModelProperty("招标单位名称")
    private java.lang.String unitName;
    @ApiModelProperty("备注")
    private java.lang.String memo;
    @ApiModelProperty("类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)")
    private java.lang.String type;
    @ApiModelProperty("招标名称")
    private java.lang.String tenderName;
    @ApiModelProperty("招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)")
    private java.lang.Integer tenderType;
    @ApiModelProperty("招标联系人")
    private java.lang.String sourceEmployeeId;
    @ApiModelProperty("招标联系人名称")
    private java.lang.String employeeName;
    @ApiModelProperty("招标联系人电话")
    private java.lang.String employeeMobile;
    @ApiModelProperty("采购方式(0-项目采购,1-单位采购)")
    private java.lang.Integer purchaseType;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiModelProperty("开标时间")
    private java.util.Date noticeBidTime;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiModelProperty("中标时间")
    private java.util.Date noticeWinbidTime;
    @ApiModelProperty("中标总额")
    private java.math.BigDecimal winbidMoney;
    @ApiModelProperty("中标总额(含税)")
    private java.math.BigDecimal winbidMoneyTax;

    private List<WinbidDetailVO> winbidDetailList = new ArrayList<>(); // 中标明细

    public List<WinbidDetailVO> getWinbidDetailList() {
        return winbidDetailList;
    }

    public void setWinbidDetailList(List<WinbidDetailVO> winbidDetailList) {
        this.winbidDetailList = winbidDetailList;
    }

    /**
     * 来源id
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 来源id
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 中标编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 中标编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发布项目ID
     */
    public java.lang.String getSourceProjectId() {
        return sourceProjectId;
    }

    /**
     * 发布项目ID
     */
    public void setSourceProjectId(java.lang.String sourceProjectId) {
        this.sourceProjectId = sourceProjectId;
    }
    /**
     * 发布项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 发布项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 发布项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 发布项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 发布组织ID
     */
    public java.lang.String getSourceOrgId() {
        return sourceOrgId;
    }

    /**
     * 发布组织ID
     */
    public void setSourceOrgId(java.lang.String sourceOrgId) {
        this.sourceOrgId = sourceOrgId;
    }
    /**
     * 发布组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 发布组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 招标单位ID
     */
    public java.lang.String getSourceUnitId() {
        return sourceUnitId;
    }

    /**
     * 招标单位ID
     */
    public void setSourceUnitId(java.lang.String sourceUnitId) {
        this.sourceUnitId = sourceUnitId;
    }
    /**
     * 招标单位名称
     */
    public java.lang.String getUnitName() {
        return unitName;
    }

    /**
     * 招标单位名称
     */
    public void setUnitName(java.lang.String unitName) {
        this.unitName = unitName;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型(1-材料采购招标，2-分包招标,3-设备采购招标，4-设备租赁招标，5-周转材租赁招标，6-其他招标)
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }
    /**
     * 招标名称
     */
    public java.lang.String getTenderName() {
        return tenderName;
    }

    /**
     * 招标名称
     */
    public void setTenderName(java.lang.String tenderName) {
        this.tenderName = tenderName;
    }
    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public java.lang.Integer getTenderType() {
        return tenderType;
    }

    /**
     * 招标方式(0-公开招标,1-邀请招标,2-询价,3-竞争性谈判,4-单一来源,5-紧急招标)
     */
    public void setTenderType(java.lang.Integer tenderType) {
        this.tenderType = tenderType;
    }
    /**
     * 招标联系人
     */
    public java.lang.String getSourceEmployeeId() {
        return sourceEmployeeId;
    }

    /**
     * 招标联系人
     */
    public void setSourceEmployeeId(java.lang.String sourceEmployeeId) {
        this.sourceEmployeeId = sourceEmployeeId;
    }
    /**
     * 招标联系人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 招标联系人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 招标联系人电话
     */
    public java.lang.String getEmployeeMobile() {
        return employeeMobile;
    }

    /**
     * 招标联系人电话
     */
    public void setEmployeeMobile(java.lang.String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }
    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public java.lang.Integer getPurchaseType() {
        return purchaseType;
    }

    /**
     * 采购方式(0-项目采购,1-单位采购)
     */
    public void setPurchaseType(java.lang.Integer purchaseType) {
        this.purchaseType = purchaseType;
    }
    /**
     * 开标时间
     */
    public java.util.Date getNoticeBidTime() {
        return noticeBidTime;
    }

    /**
     * 开标时间
     */
    public void setNoticeBidTime(java.util.Date noticeBidTime) {
        this.noticeBidTime = noticeBidTime;
    }
    /**
     * 中标时间
     */
    public java.util.Date getNoticeWinbidTime() {
        return noticeWinbidTime;
    }

    /**
     * 中标时间
     */
    public void setNoticeWinbidTime(java.util.Date noticeWinbidTime) {
        this.noticeWinbidTime = noticeWinbidTime;
    }
    /**
     * 中标总额
     */
    public java.math.BigDecimal getWinbidMoney() {
        return winbidMoney;
    }

    /**
     * 中标总额
     */
    public void setWinbidMoney(java.math.BigDecimal winbidMoney) {
        this.winbidMoney = winbidMoney;
    }
    /**
     * 中标总额(含税)
     */
    public java.math.BigDecimal getWinbidMoneyTax() {
        return winbidMoneyTax;
    }

    /**
     * 中标总额(含税)
     */
    public void setWinbidMoneyTax(java.math.BigDecimal winbidMoneyTax) {
        this.winbidMoneyTax = winbidMoneyTax;
    }
    
}
